==> qtjambi-location-debuginfo-linux-x64-6.5.4.jar: sources/QtJambiLocation/QPlaceMatchReply_shell.h <==
#ifndef QPLACEMATCHREPLY_SHELL_H
#define QPLACEMATCHREPLY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtLocation/qplacematchreply.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtLocation/qplace.h>
#include <QtLocation/qplacematchrequest.h>
#include <QtLocation/qplacereply.h>
#include <QtJambi/RegistryAPI>


class QPlaceMatchReply_shell : public QPlaceMatchReply, public QtJambiShellInterface
{
public:
    QPlaceMatchReply_shell(QObject* parent0 = nullptr);
    ~QPlaceMatchReply_shell() override;

    void abort() override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    QPlaceReply::Type type() const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPlaceMatchReply_access : public QPlaceMatchReply
{
    void __qt_setPlaces_cref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject results0);
    void __qt_setRequest_cref_QPlaceMatchRequest(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0);
    jint __qt_type(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QPLACEMATCHREPLY_SHELL_H

==> qtjambi-location-debuginfo-linux-x64-6.5.5.jar: sources/QtJambiLocation/QPlaceMatchReply_shell.h <==
#ifndef QPLACEMATCHREPLY_SHELL_H
#define QPLACEMATCHREPLY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtLocation/qplacematchreply.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtLocation/qplace.h>
#include <QtLocation/qplacematchrequest.h>
#include <QtLocation/qplacereply.h>
#include <QtJambi/RegistryAPI>


class QPlaceMatchReply_shell : public QPlaceMatchReply, public QtJambiShellInterface
{
public:
    QPlaceMatchReply_shell(QObject* parent0 = nullptr);
    ~QPlaceMatchReply_shell() override;

    void abort() override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    QPlaceReply::Type type() const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPlaceMatchReply_access : public QPlaceMatchReply
{
    void __qt_setPlaces_cref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject results0);
    void __qt_setRequest_cref_QPlaceMatchRequest(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0);
    jint __qt_type_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QPLACEMATCHREPLY_SHELL_H
